%------------------------------------------------------------
% Author:    Yasuko Matsubara 
% Email:     yasuko@cs.kumamoto-u.ac.jp
% URL:       http://www.cs.kumamoto-u.ac.jp/~yasuko/
% Date:      2016-09-15
%------------------------------------------------------------
% Copyright (C) 2015--2016 Yasuko Matsubara & Yasushi Sakurai
%------------------------------------------------------------
function [X, Ve, Vf_full, Ticks] = M_regimesnap_idx(DIR, idx, ssONLY, X, Ve, Vf_full, Ticks)
gc=[.6 .6 .6];

%------------------------%
% load event stream X
if(isempty(X)); 
    X=load([DIR,'X']);
end
% load estimated event Ve at each time-tick
if(isempty(Ve)); 
    load([DIR,'Snaps.mat']); 
end
if(size(Ticks,1) ~= size(Ve,3)); Ve=cov(Ve); end
% load forecasted events (full)
if(isempty(Vf_full)); 
    Vf_full=load([DIR,'Vf_full']); 
end
%------------------------%


%------------------------%
% find tick by index
if(size(Ve,1)==1)
    Ve_idx=Ve{idx}; 
else
    Ve_idx=Ve(:,:,idx); 
end
%------------------------%

%------------------------%
% setting: ticks
%------------------------%
[n,d]=size(X);          % event size
Ticks_idx=Ticks(idx,:); % current time ticks
tm_st=Ticks_idx(1); tm_ed=Ticks_idx(2);
tf_st=Ticks_idx(3); tf_ed=Ticks_idx(4);
mx=max(X(:)); mn=min(X(:)); % min/max 
%------------------------%
lene=tf_ed-tm_st;
ldlt=ceil(lene*0.1); 
from=tm_st-ldlt; to=tf_ed+ldlt;
if(from<1); from=1; end
if(to>length(X)); to=length(X); end
%------------------------%

%------------------------%
% if not snapshot ONLY
%------------------------%
if (~ssONLY)
    subplot(411)
    plot(X, 'color', gc); 
    hold on;
    plot(X(1:tm_ed,:)); 
    hold off;
    ylim([mn,mx]); xlim([1,n])
    M_plotLines([tm_st, tm_ed], mn, mx, 'black')
    M_plotLines([tf_st, tf_ed], mn, mx, 'red')
    legend('Original'); largefont_s(12);
    subplot(412)
    plot(1:tf_ed, Vf_full(1:tf_ed,:)); ylim([mn,mx]); xlim([1,n])
    M_plotLines([lene], mn, mx, 'black')
    M_plotLines([tf_st, tf_ed], mn, mx, 'red')
    legend('Forecast'); largefont_s(12);
    %---------------%
    subplot(2,1,2)
end
%------------------------%


%------------------------%
% snapshot plot
%------------------------%
plot(from:to, X(from:to,:), '--', 'LineWidth', 2, 'color', gc);  % org
hold on;
plot(tm_st:tf_ed-1, Ve_idx, 'LineWidth', 2);   % estimated events Ve
M_plotLines([tm_st], mn, mx, 'black') ;     
M_plotLines([tm_ed, tf_st, tf_ed], mn, mx, 'red');
xlim([from, to]); ylim([mn,mx]); 
ylabel('Value'); xlabel('Time');
largefont_s(12);
title(['Real-time forecasting : t=', num2str(tm_ed)]); 
largefont_s(12);
%------------------------%


end



function [Y] = cov(X)
Y=cell2mat(X);
Y=permute(Y, [2,3,1]);
end
